@@ -1,4 +1,5 @@
-from pytorch_optimizer.adabound import AdaBound, AdaBoundW
+from pytorch_optimizer.adabelief import AdaBelief
+from pytorch_optimizer.adabound import AdaBound
 from pytorch_optimizer.adahessian import AdaHessian
 from pytorch_optimizer.adamp import AdamP
 from pytorch_optimizer.agc import agc
@@ -9,6 +10,7 @@ from pytorch_optimizer.madgrad import MADGRAD
 from pytorch_optimizer.radam import RAdam
 from pytorch_optimizer.ranger import Ranger
 from pytorch_optimizer.ranger21 import Ranger21
+from pytorch_optimizer.sam import SAM
 from pytorch_optimizer.sgdp import SGDP
 
-__VERSION__ = '0.0.4'
+__VERSION__ = '0.0.6'
